@@ -5,4 +5,6 @@
 # your platform
 #
 PATH_TO_SIKULI_JAR=/Applications/Sikuli-IDE.app/Contents/Resources/Java/
+cd src
 java -cp "$PATH_TO_SIKULI_JAR/sikuli-script.jar" org.python.util.jython -m jython_sikuli_server
+cd ..
